package org.greenstone.gatherer.metadata;


import java.io.*;
import java.util.*;


/** This class is a static class that manages the doc.xml files */
public class DocXMLFileManager
{
    static private ArrayList doc_xml_files = new ArrayList();


    static public void clearDocXMLFiles()
    {
	doc_xml_files.clear();
    }


    static public ArrayList getMetadataExtractedFromFile(File file)
    {
	// Build up a list of metadata values extracted from this file
	ArrayList metadata_values = new ArrayList();

	// Look at each loaded doc.xml file to see if any have extracted metadata for this file
	for (int i = 0; i < doc_xml_files.size(); i++) {
	    DocXMLFile doc_xml_file = (DocXMLFile) doc_xml_files.get(i);
	    metadata_values.addAll(doc_xml_file.getMetadataExtractedFromFile(file));
	}

	return metadata_values;
    }


    static public void loadDocXMLFiles(File directory)
    {
	// Make sure the directory (archives) exists
	if (directory.exists() == false) {
	    return;
	}

	// Look recursively at each subfile of the directory for doc.xml files
	File[] directory_files = directory.listFiles();
	for (int i = 0; i < directory_files.length; i++) {
	    File child_file = directory_files[i];
	    if (child_file.isDirectory()) {
		loadDocXMLFiles(child_file);
	    }
	    else if (child_file.getName().equals("doc.xml")) {
		loadDocXMLFile(child_file);
	    }
	}
    }


    static private void loadDocXMLFile(File doc_xml_file_file)
    {
	DocXMLFile doc_xml_file = new DocXMLFile(doc_xml_file_file.getAbsolutePath());
	doc_xml_files.add(doc_xml_file);
    }
}
